@@ -19,14 +19,18 @@ from __future__ import division as _division
 from __future__ import print_function as _print_function
 
 import os as _os
+import sys as _sys
+
+from tensorflow.python.tools import module_util as _module_util
 
 # pylint: disable=g-bad-import-order
-from tensorflow.python import pywrap_tensorflow  # pylint: disable=unused-import
 
 from tensorflow._api.v1.compat.v1 import app
+from tensorflow._api.v1.compat.v1 import audio
 from tensorflow._api.v1.compat.v1 import autograph
 from tensorflow._api.v1.compat.v1 import bitwise
 from tensorflow._api.v1.compat.v1 import compat
+from tensorflow._api.v1.compat.v1 import config
 from tensorflow._api.v1.compat.v1 import data
 from tensorflow._api.v1.compat.v1 import debugging
 from tensorflow._api.v1.compat.v1 import distribute
@@ -40,15 +44,16 @@ from tensorflow._api.v1.compat.v1 import graph_util
 from tensorflow._api.v1.compat.v1 import image
 from tensorflow._api.v1.compat.v1 import initializers
 from tensorflow._api.v1.compat.v1 import io
-from tensorflow._api.v1.compat.v1 import keras
 from tensorflow._api.v1.compat.v1 import layers
 from tensorflow._api.v1.compat.v1 import linalg
 from tensorflow._api.v1.compat.v1 import lite
 from tensorflow._api.v1.compat.v1 import logging
+from tensorflow._api.v1.compat.v1 import lookup
 from tensorflow._api.v1.compat.v1 import losses
 from tensorflow._api.v1.compat.v1 import manip
 from tensorflow._api.v1.compat.v1 import math
 from tensorflow._api.v1.compat.v1 import metrics
+from tensorflow._api.v1.compat.v1 import nest
 from tensorflow._api.v1.compat.v1 import nn
 from tensorflow._api.v1.compat.v1 import profiler
 from tensorflow._api.v1.compat.v1 import python_io
@@ -56,6 +61,7 @@ from tensorflow._api.v1.compat.v1 import quantization
 from tensorflow._api.v1.compat.v1 import queue
 from tensorflow._api.v1.compat.v1 import ragged
 from tensorflow._api.v1.compat.v1 import random
+from tensorflow._api.v1.compat.v1 import raw_ops
 from tensorflow._api.v1.compat.v1 import resource_loader
 from tensorflow._api.v1.compat.v1 import saved_model
 from tensorflow._api.v1.compat.v1 import sets
@@ -66,9 +72,11 @@ from tensorflow._api.v1.compat.v1 import strings
 from tensorflow._api.v1.compat.v1 import summary
 from tensorflow._api.v1.compat.v1 import sysconfig
 from tensorflow._api.v1.compat.v1 import test
+from tensorflow._api.v1.compat.v1 import tpu
 from tensorflow._api.v1.compat.v1 import train
 from tensorflow._api.v1.compat.v1 import user_ops
 from tensorflow._api.v1.compat.v1 import version
+from tensorflow._api.v1.compat.v1 import xla
 from tensorflow.lite.python.lite import _import_graph_def as import_graph_def
 from tensorflow.python import AggregationMethod
 from tensorflow.python import Assert
@@ -77,6 +85,7 @@ from tensorflow.python import ConditionalAccumulator
 from tensorflow.python import ConditionalAccumulatorBase
 from tensorflow.python import ConfigProto
 from tensorflow.python import Constant as constant_initializer
+from tensorflow.python import CriticalSection
 from tensorflow.python import DType
 from tensorflow.python import DeviceSpec
 from tensorflow.python import Dimension
@@ -116,7 +125,6 @@ from tensorflow.python import PriorityQueue
 from tensorflow.python import QueueBase
 from tensorflow.python import RandomNormal as random_normal_initializer
 from tensorflow.python import RandomShuffleQueue
-from tensorflow.python import RandomUniform as random_uniform_initializer
 from tensorflow.python import ReaderBase
 from tensorflow.python import RegisterGradient
 from tensorflow.python import RunMetadata
@@ -135,7 +143,6 @@ from tensorflow.python import TensorArray
 from tensorflow.python import TensorInfo
 from tensorflow.python import TensorShape
 from tensorflow.python import TextLineReader
-from tensorflow.python import TruncatedNormal as truncated_normal_initializer
 from tensorflow.python import UnconnectedGradients
 from tensorflow.python import UniformUnitScaling as uniform_unit_scaling_initializer
 from tensorflow.python import VarLenFeature
@@ -192,6 +199,7 @@ from tensorflow.python import assign_sub
 from tensorflow.python import atan
 from tensorflow.python import atan2
 from tensorflow.python import atanh
+from tensorflow.python import batch_function as nondifferentiable_batch_function
 from tensorflow.python import batch_gather
 from tensorflow.python import batch_to_space
 from tensorflow.python import batch_to_space_nd
@@ -212,7 +220,6 @@ from tensorflow.python import clip_by_average_norm
 from tensorflow.python import clip_by_global_norm
 from tensorflow.python import clip_by_norm
 from tensorflow.python import clip_by_value
-from tensorflow.python import colocate_with
 from tensorflow.python import complex
 from tensorflow.python import concat
 from tensorflow.python import cond
@@ -235,7 +242,7 @@ from tensorflow.python import decode_base64
 from tensorflow.python import decode_compressed
 from tensorflow.python import decode_csv
 from tensorflow.python import decode_json_example
-from tensorflow.python import decode_raw
+from tensorflow.python import decode_raw_v1 as decode_raw
 from tensorflow.python import delete_session_tensor
 from tensorflow.python import depth_to_space
 from tensorflow.python import dequantize
@@ -270,6 +277,7 @@ from tensorflow.python import fake_quant_with_min_max_vars_gradient
 from tensorflow.python import fake_quant_with_min_max_vars_per_channel
 from tensorflow.python import fake_quant_with_min_max_vars_per_channel_gradient
 from tensorflow.python import fill
+from tensorflow.python import fingerprint
 from tensorflow.python import fixed_size_partitioner
 from tensorflow.python import floor
 from tensorflow.python import floor_div
@@ -278,6 +286,7 @@ from tensorflow.python import floor_mod as mod
 from tensorflow.python import floordiv
 from tensorflow.python import foldl
 from tensorflow.python import foldr
+from tensorflow.python import function
 from tensorflow.python import gather
 from tensorflow.python import gather_nd
 from tensorflow.python import get_collection
@@ -339,7 +348,6 @@ from tensorflow.python import logical_xor
 from tensorflow.python import make_ndarray
 from tensorflow.python import make_template
 from tensorflow.python import make_tensor_proto
-from tensorflow.python import map_fn
 from tensorflow.python import matching_files
 from tensorflow.python import matmul
 from tensorflow.python import matrix_band_part
@@ -392,6 +400,7 @@ from tensorflow.python import random_normal
 from tensorflow.python import random_poisson
 from tensorflow.python import random_shuffle
 from tensorflow.python import random_uniform
+from tensorflow.python import random_uniform_initializer
 from tensorflow.python import range
 from tensorflow.python import rank
 from tensorflow.python import read_file
@@ -497,10 +506,11 @@ from tensorflow.python import stack
 from tensorflow.python import stop_gradient
 from tensorflow.python import strided_slice
 from tensorflow.python import string_join
-from tensorflow.python import string_split
 from tensorflow.python import string_strip
 from tensorflow.python import string_to_hash_bucket_fast
 from tensorflow.python import string_to_hash_bucket_strong
+from tensorflow.python import string_to_hash_bucket_v1 as string_to_hash_bucket
+from tensorflow.python import string_to_number_v1 as string_to_number
 from tensorflow.python import substr_deprecated as substr
 from tensorflow.python import subtract
 from tensorflow.python import svd
@@ -508,8 +518,11 @@ from tensorflow.python import tables_initializer
 from tensorflow.python import tan
 from tensorflow.python import tanh
 from tensorflow.python import tensor_scatter_add
+from tensorflow.python import tensor_scatter_add as tensor_scatter_nd_add
 from tensorflow.python import tensor_scatter_sub
+from tensorflow.python import tensor_scatter_sub as tensor_scatter_nd_sub
 from tensorflow.python import tensor_scatter_update
+from tensorflow.python import tensor_scatter_update as tensor_scatter_nd_update
 from tensorflow.python import tensordot
 from tensorflow.python import tile
 from tensorflow.python import timestamp
@@ -527,6 +540,7 @@ from tensorflow.python import truediv
 from tensorflow.python import truncate_div as truncatediv
 from tensorflow.python import truncate_mod as truncatemod
 from tensorflow.python import truncated_normal
+from tensorflow.python import truncated_normal_initializer
 from tensorflow.python import tuple
 from tensorflow.python import unique
 from tensorflow.python import unique_with_counts
@@ -542,15 +556,17 @@ from tensorflow.python import variable_axis_size_partitioner
 from tensorflow.python import variable_op_scope
 from tensorflow.python import variable_scope
 from tensorflow.python import variables_initializer
+from tensorflow.python import vectorized_map
 from tensorflow.python import verify_tensor_all_finite
 from tensorflow.python import where
+from tensorflow.python import where_v2
 from tensorflow.python import while_loop
 from tensorflow.python import write_file
 from tensorflow.python import zeros
 from tensorflow.python import zeros_like
 from tensorflow.python import zeta
-from tensorflow.python.compat.compat import disable_v2_behavior
-from tensorflow.python.compat.compat import enable_v2_behavior
+from tensorflow.python.compat.v2_compat import disable_v2_behavior
+from tensorflow.python.compat.v2_compat import enable_v2_behavior
 from tensorflow.python.eager.wrap_function import wrap_function
 from tensorflow.python.framework.constant_op import constant_v1 as constant
 from tensorflow.python.framework.dtypes import QUANTIZED_DTYPES
@@ -579,6 +595,7 @@ from tensorflow.python.framework.dtypes import uint32
 from tensorflow.python.framework.dtypes import uint64
 from tensorflow.python.framework.dtypes import uint8
 from tensorflow.python.framework.dtypes import variant
+from tensorflow.python.framework.ops import _colocate_with as colocate_with
 from tensorflow.python.framework.ops import disable_eager_execution
 from tensorflow.python.framework.ops import init_scope
 from tensorflow.python.framework.tensor_shape import dimension_at_index
@@ -586,6 +603,8 @@ from tensorflow.python.framework.tensor_shape import dimension_value
 from tensorflow.python.framework.tensor_shape import disable_v2_tensorshape
 from tensorflow.python.framework.tensor_shape import enable_v2_tensorshape
 from tensorflow.python.framework.tensor_spec import TensorSpec
+from tensorflow.python.framework.tensor_util import constant_value as get_static_value
+from tensorflow.python.framework.tensor_util import is_tensor
 from tensorflow.python.framework.versions import COMPILER_VERSION
 from tensorflow.python.framework.versions import COMPILER_VERSION as __compiler_version__
 from tensorflow.python.framework.versions import CXX11_ABI_FLAG
@@ -599,31 +618,47 @@ from tensorflow.python.framework.versions import MONOLITHIC_BUILD
 from tensorflow.python.framework.versions import MONOLITHIC_BUILD as __monolithic_build__
 from tensorflow.python.framework.versions import VERSION
 from tensorflow.python.framework.versions import VERSION as __version__
+from tensorflow.python.module.module import Module
 from tensorflow.python.ops.array_ops import newaxis
 from tensorflow.python.ops.check_ops import ensure_shape
 from tensorflow.python.ops.confusion_matrix import confusion_matrix_v1 as confusion_matrix
-from tensorflow.python.ops.gen_parsing_ops import string_to_number
+from tensorflow.python.ops.control_flow_grad import switch_case
 from tensorflow.python.ops.gen_spectral_ops import fft
 from tensorflow.python.ops.gen_spectral_ops import fft2d
 from tensorflow.python.ops.gen_spectral_ops import fft3d
 from tensorflow.python.ops.gen_spectral_ops import ifft
 from tensorflow.python.ops.gen_spectral_ops import ifft2d
 from tensorflow.python.ops.gen_spectral_ops import ifft3d
-from tensorflow.python.ops.gen_string_ops import string_to_hash_bucket
 from tensorflow.python.ops.logging_ops import print_v2 as print
-from tensorflow.python.ops.ragged.ragged_tensor import RaggedTensor
+from tensorflow.python.ops.map_fn import map_fn
+from tensorflow.python.ops.ragged.ragged_squeeze_op import RaggedTensor
+from tensorflow.python.ops.ragged.ragged_string_ops import string_split
 from tensorflow.python.ops.script_ops import eager_py_func as py_function
+from tensorflow.python.ops.script_ops import numpy_function
 from tensorflow.python.ops.state_ops import batch_scatter_update
 from tensorflow.python.ops.variable_scope import AUTO_REUSE
 from tensorflow.python.ops.variable_scope import disable_resource_variables
 from tensorflow.python.ops.variable_scope import enable_resource_variables
+from tensorflow.python.ops.variable_scope import resource_variables_enabled
 from tensorflow.python.ops.variable_scope import variable_creator_scope_v1 as variable_creator_scope
 from tensorflow.python.platform.tf_logging import get_logger
 
-from tensorflow.python.tools import component_api_helper as _component_api_helper
-_component_api_helper.package_hook(
-    parent_package_str=__name__,
-    child_package_str=('tensorflow_estimator.python.estimator.api.estimator'))
+# Hook external TensorFlow modules.
+_current_module = _sys.modules[__name__]
+try:
+  from tensorflow_estimator.python.estimator.api._v1 import estimator
+  _current_module.__path__ = (
+      [_module_util.get_parent_dir(estimator)] + _current_module.__path__)
+except ImportError:
+  pass
+
+try:
+  from tensorflow.python.keras.api._v1 import keras
+  _current_module.__path__ = (
+      [_module_util.get_parent_dir(keras)] + _current_module.__path__)
+except ImportError:
+  pass
+
 
 from tensorflow.python.platform import flags  # pylint: disable=g-import-not-at-top
 app.flags = flags  # pylint: disable=undefined-variable
